@@ -1,13 +1,13 @@
 from datetime import timedelta
 
 from django.db import models
-from django.utils import timezone
 from django.db.models import Q
+from django.utils import timezone
 
-from . import app_settings
+from .app_settings import app_settings
 
 
-class InvitationManager(models.Manager):
+class BaseInvitationManager(models.Manager):
 
     def all_expired(self):
         return self.filter(self.expired_q())
@@ -16,7 +16,8 @@ class InvitationManager(models.Manager):
         return self.exclude(self.expired_q())
 
     def expired_q(self):
-        sent_threshold = timezone.now() - timedelta(days=app_settings.INVITATION_EXPIRY)
+        sent_threshold = timezone.now() - timedelta(
+            days=app_settings.INVITATION_EXPIRY)
         q = Q(accepted=True) | Q(sent__lt=sent_threshold)
         return q
 
